/* -*- Mode: C++; c-file-style: "gnu"; indent-tabs-mode:nil -*- */
/*
 * Copyright (c) 2011 University of California, Los Angeles
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
 */

#ifndef _CCNB_PARSER_INTEREST_VISITOR_H_
#define _CCNB_PARSER_INTEREST_VISITOR_H_

#include "ccnb-parser-void-depth-first-visitor.h"
#include "ccnb-parser-name-components-visitor.h"
#include "ccnb-parser-non-negative-integer-visitor.h"

namespace ns3 {
namespace CcnbParser {

/**
 * \ingroup ccnx-ccnb
 * \brief Visitor that fills fields in CcnxInterestHeader
 *
 * Usage example:
 * \code
 *   Ptr<CcnxInterestHeader> header = Create<CcnxInterestHeader> ();
 *   Ptr<CcnbParser::Block> root = CcnbParser::Block::ParseBlock (i);
 *   InterestVisitor visitor;
 *   root->accept (visitor, *header); 
 * \endcode
 */
class InterestVisitor : public VoidDepthFirstVisitor
{
public:
  virtual void visit (Dtag &n, boost::any param/*should be CcnxInterestHeader&*/);
};

}
}

#endif // _CCNB_PARSER_INTEREST_VISITOR_H_
